.. include:: common.txt

:mod:`pygame.cursors`
=====================

.. autopgmodule:: pygame.cursors
   :members:

Example code for creating and settings cursors. (Click the mouse to switch cursor)

.. literalinclude:: code_examples/cursors_module_example.py
